layer

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RenderOn

func RenderOn(canvas canvas.Canvas, fragment Fragment)

Types

type Fragment

type Fragment struct {
	// Points of the fragment in screen coordinates
	Points point.Points
	// Fill color if assigned is result of shading by taking into account
	// material, lights and shading algorithm.
	Fill *color.Color
	// Stroke color if assigned is result of shading by taking into account
	// material, lights and shading algorithm.
	Stroke *color.Color
	// Options contains all the style options passed in on  the face.
	Options map[string]string
}

Fragment contains only the information needed to render the face on a canvas.

type Layer

type Layer interface {
	RenderOn(canvas.Canvas)
}

Layer

Directories

Path Synopsis
bsp
internal
ordercheck
Package ordercheck is a deterministic repro + regression harness for painter-order (visibility) correctness, shared by the ordering layers.
Package ordercheck is a deterministic repro + regression harness for painter-order (visibility) correctness, shared by the ordering layers.
Package nsort renders a scene with a Newell–Newell–Sancha depth sort: a view-DEPENDENT painter's order recomputed per frame for the current eye.
Package nsort renders a scene with a Newell–Newell–Sancha depth sort: a view-DEPENDENT painter's order recomputed per frame for the current eye.

Jump to