Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Fragment ¶
type Fragment struct {
// Points of the fragment in screen coordinates
Points point.Points
// Fill color if assigned is result of shading by taking into account
// material, lights and shading algorithm.
Fill *color.Color
// Stroke color if assigned is result of shading by taking into account
// material, lights and shading algorithm.
Stroke *color.Color
// Options contains all the style options passed in on the face.
Options map[string]string
}
Fragment contains only the information needed to render the face on a canvas.
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
ordercheck
Package ordercheck is a deterministic repro + regression harness for painter-order (visibility) correctness, shared by the ordering layers.
|
Package ordercheck is a deterministic repro + regression harness for painter-order (visibility) correctness, shared by the ordering layers. |
|
Package nsort renders a scene with a Newell–Newell–Sancha depth sort: a view-DEPENDENT painter's order recomputed per frame for the current eye.
|
Package nsort renders a scene with a Newell–Newell–Sancha depth sort: a view-DEPENDENT painter's order recomputed per frame for the current eye. |
Click to show internal directories.
Click to hide internal directories.