bsort

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewLayerForScene

func NewLayerForScene(scene *seen.Scene) layer.Layer

Types

type Layer

type Layer struct {
	// contains filtered or unexported fields
}

Layer implements the layer.Layer interface.

func (*Layer) RenderOn

func (s *Layer) RenderOn(canvas canvas.Canvas)

RenderOn renders all faces that are part of the shapes and objects in the scene on to the given canvas

type Planes

type Planes []bsp.Plane

func (Planes) EnterGroup

func (b Planes) EnterGroup()

func (Planes) LeaveGroup

func (b Planes) LeaveGroup()

func (Planes) VisitLight

func (b Planes) VisitLight(light seen.Light, model matrix.Matrix)

func (*Planes) VisitObject

func (b *Planes) VisitObject(object seen.Object, model matrix.Matrix)

type Shader

type Shader struct {
	Cache ShaderCache
	// contains filtered or unexported fields
}

func NewShader

func NewShader(cache ShaderCache) *Shader

func (*Shader) EnterGroup

func (v *Shader) EnterGroup()

func (*Shader) LeaveGroup

func (v *Shader) LeaveGroup()

func (*Shader) Shade

func (shader *Shader) Shade(scene *seen.Scene, projection, viewport matrix.Matrix) bool

func (*Shader) VisitLight

func (v *Shader) VisitLight(l seen.Light, model matrix.Matrix)

func (*Shader) VisitObject

func (v *Shader) VisitObject(object seen.Object, model matrix.Matrix)

type ShaderCache

type ShaderCache map[int]ShaderFragment

type ShaderFragment

type ShaderFragment struct {
	face.Coordinates
	Fill   *color.Color
	Stroke *color.Color
}

Directories

Path Synopsis

Jump to