Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ByZ ¶
type ByZ []zfragment
ByZ implements sorting by comparing the Z of the Barycenter of the Projected points
type Layer ¶
type Layer struct {
// contains filtered or unexported fields
}
Layer implements the layer.Layer interface. Layer extends seen.Scene with a function to paint the the scene on a Painter.
func (*Layer) FlushCache ¶
func (s *Layer) FlushCache()
FlushCache removes all elements from the cache. This may be necessary if you add and remove many shapes from the scene's groups since this cache has no eviction policy.
Click to show internal directories.
Click to hide internal directories.